# Aphelo Client

The official Python SDK for **Aphelo**, a high-performance, event-driven, C++ in-memory caching database.

## Installation
```bash
pip install aphelo-client

## Quickstart

Make sure your Aphelo database is running via Docker:

```bash
docker run -d -p 1234:1234 pranitgarje/aphelo-db
```

Then, connect to it in Python:

```python
from aphelo import ApheloClient

db = ApheloClient()
db.set("hello", "world")
print(db.get("hello"))